@@ -51,19 +51,11 @@ public:
 
 public:
 
-  /** @name Standard constructors and destructors. */
-  //@{
   /**
    * Default constructor.
    */
   ParticleData();
 
-  /**
-   * Destructor.
-   */
-  virtual ~ParticleData();
-  //@}
-
   /** @name The Create methods are special interfaces for ParticleData
       classes. */
   //@{
@@ -368,6 +360,13 @@ public:
       iColour() == PDT::Colour8;
   }
 
+  /**
+   * Return what kind of colour charge this particle carries
+   */
+  PDT::ColouredInteraction colouredInteraction() const {
+    return theColouredInteraction;
+  }
+
   /**
    * Specify if particle is to be considered stable according to \a
    * stab.
@@ -631,6 +630,15 @@ private:
    */
   PDT::Colour theColour;
 
+  /**
+   * The coloured interaction of this particle
+   */
+  PDT::ColouredInteraction theColouredInteraction;
+
+  /**
+   * The nonabelian interaction of this particle
+   */
+
   /**
    * A pointer to an object capable to generate a mass for a particle
    * of this type.
@@ -715,6 +723,11 @@ private:
    */
   PDT::Colour theDefColour;
 
+  /**
+   * Helper variable to keep track of the default coloured interaction.
+   */
+  PDT::ColouredInteraction theDefColouredInteraction;
+
   /**
    * Utility function for the interface.
    */
@@ -911,6 +924,21 @@ private:
    */
   long defColour() const;
 
+  /**
+   * Utility function for the interface.
+   */
+  void setColouredInteraction(long);
+
+  /**
+   * Utility function for the interface.
+   */
+  long getColouredInteraction() const;
+
+  /**
+   * Utility function for the interface.
+   */
+  long defColouredInteraction() const;
+
   /**
    * Utility function for the interface.
    */
